﻿using System;
using System.Collections.Generic;
using System.Collections;
using System.Linq;
using System.Text;
using Recurso_Administrativo.Persistencia;



/***********************************************************************************************************************************
 *   Nombre: ExpedienteF1Servicio
 *   Fecha: 07/11/2011 (San Prosdócimo de Padua)
 *   Descripción: Clase se que encargará por medio de los diferentes métodos implementados, realizar las consultas, insercciones y 
 *   actualizaciones a la tabla de Expedientes en la fase 1.
 *   Autor: José Juan Alvarado Almenara
 ***********************************************************************************************************************************/
namespace Recurso_Administrativo.Clases
{
    partial class ExpedienteF1Servicio
    {
        LinqDBDataContext dc = new LinqDBDataContext();  // Creación de la conexion a la base de datos.

        /*************************************************************************************************************************
        * Metodo: ExistRegistro
        * Recibe: Objeto T_Expediente_F1 a añadir a la tabla
        * Devuelve: Booleano 
        * Autor: José Juan Alvarado Almenara
        * Fecha: 07/11/2011 (San Prosdócimo de Padua)
        * Descripcion: Comprobamos la existencia de un expediente a traves de su número. 
        *************************************************************************************************************************/

        internal bool ExistRegistro(string nReg)  
        {
            bool sw = false;

            T_EXPEDIENTE_F1 _expF1 = new T_EXPEDIENTE_F1();
            var expF1 = from u in dc.T_EXPEDIENTE_F1
                        where u.EF1_NUMREG == nReg.ToUpper()
                        select u;
            if (expF1.Count() == 1)
                sw = true;
            return sw;
        }

        /*************************************************************************************************************************
        * Metodo: AddExpediente
        * Recibe: Objeto T_Expediente_F1 a añadir a la tabla
        * Devuelve: 
        * Autor: José Juan Alvarado Almenara
        * Fecha: 07/11/2011 (San Prosdócimo de Padua)
        * Descripcion: Añadimos un nuevo expediente a la base de datos
        *************************************************************************************************************************/

        internal void AddExpediente(T_EXPEDIENTE_F1 _expF1)
        {
            dc.T_EXPEDIENTE_F1.InsertOnSubmit(_expF1);
            dc.SubmitChanges();
        }


        /*************************************************************************************************************************
        * Metodo: GetExpedienteF1
        * Recibe: int (Clave del registro)
        * Devuelve: Objeto T_Expediente_F1.
        * Autor: José Juan Alvarado Almenara
        * Fecha: 07/11/2011 (San Prosdócimo de Padua)
        * Descripcion: Obtener un registro determinado consultando por su clave.
        *************************************************************************************************************************/

        internal T_EXPEDIENTE_F1 GetExpedienteF1(int ID)
        {
            var expF1 = from u in dc.T_EXPEDIENTE_F1
                        where u.EF1_CLAVE == ID
                        select u;
            if (expF1.Count() > 0)
            {
                return expF1.First();
            }
            else
                return null;
        }

        /*************************************************************************************************************************
         * Metodo: GetPendienteValidar
         * Recibe: 
         * Devuelve: List - lista de todos los expedientes pendientes de ser validados por el Letrado.
         * Autor: José Juan Alvarado Almenara
         * Fecha: 16/11/2011 (Santa Margarita de Escocia)
         * Descripcion: Necesitamos cargar el grid con los expedientes pendientes de ser validado.Por medio de la consulta 
         *              que se realiza, obtenemos todos estos expedientes y los cargamos en una lista.
         *************************************************************************************************************************/

        internal List<ExpedienteGrid> GetPendienteValidar()
        {
            ExpedienteGrid _expGrid; 
            TipoRecursoServicio _trS = new TipoRecursoServicio();
            List<ExpedienteGrid> listExpGrid = new List<ExpedienteGrid>();
            
            var exp1 = from u in dc.T_EXPEDIENTE_F1
                       where u.EF1_USR_VAL_CF == null // No debe haber sido validado
                       select u;

            foreach (T_EXPEDIENTE_F1 i in exp1)
            {
                _expGrid = new ExpedienteGrid();
                listExpGrid.Add(_expGrid.CargarExpGrid(i, _trS.getTipRec(i.EF1_TR_CF)));
            }
            if (exp1.Count() > 0)
                return listExpGrid;
            else
                return null;
        }

        /*************************************************************************************************************************
         * Metodo: ActualizarExpF1
         * Recibe: 
         * Devuelve: 
         * Autor: José Juan Alvarado Almenara
         * Fecha: 16/11/2011 (Santa Margarita de Escocia)
         * Descripcion: Actilizar el registro en la Tabla T_Expedient_F1 con el que estamos trabajando.
         *************************************************************************************************************************/

        internal void ActualizarExpF1()
        {   
            dc.SubmitChanges();
        }

        /*************************************************************************************************************************
         * Metodo: GetExpSendCCDD
         * Recibe: 
         * Devuelve: List - lista de todos los expedientes validados pendientes de remitir al CCDD correspondiente.
         * Autor: José Juan Alvarado Almenara
         * Fecha: 21/11/2011 (San Gelasio I)
         * Descripcion: Necesitamos cargar el grid con los expedientes pendientes de mandar al CC.DD..Por medio de la consulta 
         *              que se realiza, obtenemos todos estos expedientes y los cargamos en una lista.
         *************************************************************************************************************************/

        internal List<ExpedienteGrid> GetExpSendCCDD()
        {
            ExpedienteGrid _expGrid;
            TipoRecursoServicio _trS = new TipoRecursoServicio();
            List<ExpedienteGrid> listExpGrid = new List<ExpedienteGrid>();

           
            var exp1 = from u in dc.T_EXPEDIENTE_F1
                       where u.EF1_USR_VAL_CF != null && u.EF1_FECRECCD == null  // Esta validado y no tiene fecha de recep. en el CC.DD.
                       select u;

            foreach (T_EXPEDIENTE_F1 i in exp1)
            {
                _expGrid = new ExpedienteGrid();
                listExpGrid.Add(_expGrid.CargarExpGrid(i, _trS.getTipRec(i.EF1_TR_CF)));
            }
            if (exp1.Count() > 0)
                return listExpGrid;
            else
                return null;
        }

        /*************************************************************************************************************************
          * Metodo: GetExpSendCCDD
          * Recibe: 
          * Devuelve: List - lista de todos los expedientes validados pendientes de remitir al CCDD correspondiente.
          * Autor: José Juan Alvarado Almenara
          * Fecha: 22/11/2011 (Santa Cecilia)
          * Descripcion: Necesitamos cargar el grid con los expedientes pendientes de mandar al CC.DD..Por medio de la consulta 
          *              que se realiza, obtenemos todos estos expedientes y los cargamos en una lista.
          *************************************************************************************************************************/

        internal List<ExpedienteGrid> GetExpF2(int CCDD_ID)
        {
            ExpedienteGrid _expGrid;
            TipoRecursoServicio _trS = new TipoRecursoServicio();
            ExpedienteF2Servicio _expF2Ser = new ExpedienteF2Servicio();
            T_EXPEDIENTE_F2 _expF2 = new T_EXPEDIENTE_F2();
            List<ExpedienteGrid> listExpGrid = new List<ExpedienteGrid>();
            bool bolSw;

            var exp1 = from u in dc.T_EXPEDIENTE_F1
                       where u.EF1_CD_CF == CCDD_ID && u.EF1_FECRECCD != null // Extraeremos los expedientes que ya se han enviado al CCDD correspondiente
                       select u;

            foreach (T_EXPEDIENTE_F1 i in exp1)
            {
                _expF2 = _expF2Ser.GetRegistro(i.EF1_CLAVE);
                bolSw = true;
                if (_expF2 != null)
                    if (_expF2.EF2_FECSOLINFLET != null)
                        bolSw = false;

                if ((_expF2 == null) || (_expF2.EF2_DE_CF == null) || (_expF2.EF2_DE_CF == 0) || (_expF2.EF2_DE_CF == 3)) //Mostraremos aquellos expedientes que no tengan en entrada en Fase2 o que no esten inadmitidos o desestimados
                {
                    if (bolSw) // si se ha rellenado la fecha de solicitud al letrado es que ha finalizado la fase 2 correctamente
                    {
                         _expGrid = new ExpedienteGrid();
                         listExpGrid.Add(_expGrid.CargarExpGrid(i, _trS.getTipRec(i.EF1_TR_CF)));
                    }
                }
            }
            if (exp1.Count() > 0)
                return listExpGrid;
            else
                return null;
        }
    }

}
