﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Recurso_Administrativo.Persistencia;


/***********************************************************************************************************************************
 *   Nombre: ExpedienteF2Servicio
 *   Fecha: 14/11/2011
 *   Descripción: Clase se que encargará por medio de los diferentes métodos implementados, realizar las consultas, insercciones y 
 *   actualizaciones a la tabla de Expedientes en la fase 2.
 *   Autor: José Juan Alvarado Almenara
 ***********************************************************************************************************************************/
namespace Recurso_Administrativo.Clases
{
    public class ExpedienteF2Servicio
    {
        LinqDBDataContext dc = new LinqDBDataContext(); //Conexión a la BBDD

        /*************************************************************************************************************************
        * Metodo: GetRegistro
        * Recibe: Entero (int) clave del registro
        * Devuelve: Objetos T_Expediente_F2
        * Autor: José Juan Alvarado Almenara
        * Fecha: 14/11/2011
        * Descripcion: Devolvemos si existe, el registro consultado por su clave.
        *************************************************************************************************************************/

        internal T_EXPEDIENTE_F2 GetRegistro(int ID)
        {
            T_EXPEDIENTE_F2 _expF2 = new T_EXPEDIENTE_F2();
            var expF2 = from u in dc.T_EXPEDIENTE_F2
                        where u.EF2_EF1_CF == ID
                        select u;
            if (expF2.Count() == 1)
                return expF2.First();
            else
                return null;
        }

        /*************************************************************************************************************************
        * Metodo: AddExpediente
        * Recibe: Objeto T_Expediente_F2 a añadir a la tabla
        * Devuelve: 
        * Autor: José Juan Alvarado Almenara
        * Fecha: 14/11/2011
        * Descripcion: Añadimos un nuevo expediente a la base de datos
        *************************************************************************************************************************/

        internal void AddExpediente(T_EXPEDIENTE_F2 _expF2)
        {
            dc.T_EXPEDIENTE_F2.InsertOnSubmit(_expF2);
            dc.SubmitChanges();
        }

        /*************************************************************************************************************************
        * Metodo: ActualizarExpF2
        * Recibe: 
        * Devuelve: 
        * Autor: José Juan Alvarado Almenara
        * Fecha: 14/11/2011
        * Descripcion: Actilizar el registro en la Tabla T_Expediente_F2 con el que estamos trabajando.
        *************************************************************************************************************************/

        internal void ActualizarExpF2()
        {
            dc.SubmitChanges();
        }

        /*************************************************************************************************************************
        * Metodo: GetExpF3
        * Recibe: 
        * Devuelve: List - lista de todos los expedientes que se encuentran en Fase 3.
        * Autor: José Juan Alvarado Almenara
        * Fecha: 24/11/2011
        * Descripcion: Devuelve una lista con todos los expedientes que estan pendientes de finalizar en la fase 3.
        *************************************************************************************************************************/

        internal List<ExpedienteGrid> GetExpF3()  
        {
            List<ExpedienteGrid> listExpGrid = new List<ExpedienteGrid>();
            ExpedienteF1Servicio _ExpF1Ser = new ExpedienteF1Servicio();
            ExpedienteF2Servicio _ExpF2Ser = new ExpedienteF2Servicio();
            ExpedienteF3Servicio _ExpF3Ser = new ExpedienteF3Servicio();
            TipoRecursoServicio _trS = new TipoRecursoServicio();
            T_EXPEDIENTE_F1 _ExpF1 = new T_EXPEDIENTE_F1();
            T_EXPEDIENTE_F3 _ExpF3 = new T_EXPEDIENTE_F3();
            ExpedienteGrid _expGrid;

            bool bolSw;
            //Consultamos los expedientes que han pasado/superado la fase 2
            var exp2 = from u in dc.T_EXPEDIENTE_F2
                       where (u.EF2_DE_CF == null || u.EF2_DE_CF == 0) && (u.EF2_FECSOLINFLET != null) 
                       select u;

            foreach (T_EXPEDIENTE_F2 i in exp2)
            {
                bolSw = false;
                _ExpF3 = _ExpF3Ser.GetExpF3(i.EF2_EF1_CF);

                if (_ExpF3 == null) // Si no existe es que no se ha grabado nada del exp. en la fase 3
                {
                    _ExpF1 = _ExpF1Ser.GetExpedienteF1(i.EF2_EF1_CF);
                    bolSw = true;
                }
                else // Si existe en Fase 3 es que aun tiene datos pendientes de grabar
                {
                    if (_ExpF3.EF3_FECENVINTER == null)
                    {
                        _ExpF1 = _ExpF1Ser.GetExpedienteF1(_ExpF3.EF3_EF1_CF);
                        bolSw = true;
                    }
                }

                if (bolSw)
                {
                    _expGrid = new ExpedienteGrid();
                    listExpGrid.Add(_expGrid.CargarExpGrid(_ExpF1, _trS.getTipRec(_ExpF1.EF1_TR_CF)));
                }
            }
            if (exp2.Count() > 0)
                return listExpGrid;
            else
                return null;
        }

    }
}
