﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Recurso_Administrativo.Persistencia;

/***********************************************************************************************************************************
 *   Nombre: TercerosServicio
 *   Fecha: 12/11/2011 (San Prosdócimo de Padua)
 *   Descripción: ESta clase se encargará de la consultas, altas a la tabla de terceros, así como la verificación de los NIF
 *   Autor: José Juan Alvarado Almenara
 ***********************************************************************************************************************************/

namespace Recurso_Administrativo.Clases
{

    internal class TercerosServicio
    {
        LinqDBDataContext dc = new LinqDBDataContext();

        internal T_TERCEROS getTercero(string nif)  // Consulta para comprobar si ya esta dado del alta el tercero
        {

            var terc = from u in dc.T_TERCEROS
                       where u.TER_NIF == nif
                       select u; 
            if (terc.Count() > 0)
                return terc.First();  
            else
                return null;
        }

        internal int geIDfTercero(string nif)  // Consulta para comprobar si ya esta dado del alta el tercero
        {

            var terc = from u in dc.T_TERCEROS
                       where u.TER_NIF == nif
                       select u;
            if (terc.Count() > 0)
                return terc.First().TER_CLAVE;
            else
                return 0;
        }

        internal T_TERCEROS getTerceroId(int ID)  // Obtener los datos del tercero
        {
            var terc = from u in dc.T_TERCEROS
                       where u.TER_CLAVE == ID
                       select u;
            if (terc.Count() > 0)
                return terc.First();
            else
                return null;
        }

        internal void AddTercero(T_TERCEROS _terc)
        {
            dc.T_TERCEROS.InsertOnSubmit(_terc);
            dc.SubmitChanges();
        }


        internal bool validarNif(string nif) //Valicaciones de los NIF/NIE
        {
            string strLetra = "";
            Boolean sw = false;
            int intNum = 0;
            char chrLet;
            const string strLet = "TRWAGMYFPDXBNJZSQVHLCKET";  //Letras del nif

            if (nif.Length == 9)
            {
                try  // Se pone un try para coger la excepción en caso de que no venga un número
                {
                    intNum = int.Parse(nif.Substring(0, 8));
                    strLetra = nif.Substring(8, 1).ToUpper();
                    switch (char.ToUpper(nif[0]))
                    {
                        case 'X':
                            chrLet = strLet[intNum % 23];
                            break;
                        case 'Y':
                            chrLet = strLet[(10000000 + intNum) % 23];
                            break;
                        case 'Z':
                            chrLet = strLet[(20000000 + intNum) % 23];
                            break;
                        default:
                            chrLet = strLet[intNum % 23];
                            break;
                    }
                    if (char.Parse(strLetra) == chrLet)
                        sw = true;
                    else
                        sw = false;
                }
                catch (Exception ex)
                {
                }
            }
            return sw;
        }


        internal Boolean validarCIF(String strCif) // Comprobar el CIF
        {
            const string strLet = "JABCDEGHI";
            String strNum = strCif.Substring(1, 7);
            int intPar = 0, intImpar = 0, intSum = 0;
            int intDC;
            Boolean sw = false;

            if (strCif.Substring(0, 1).ToUpper().Equals("X"))
                return false;
            for (int i = 0; i < strNum.Length; i++)
            {
                if (i % 2 != 0)
                    intPar = intPar + (int.Parse(strNum.Substring(i, 1)));
                else
                {
                    intImpar = (int.Parse(strNum.Substring(i, 1))) * 2;
                    intSum = intSum + (intImpar / 10) + (intImpar % 10);
                }
            }
            intSum = intSum + intPar;
            intSum = (10 - (intSum % 10)) % 10;
            try
            {
                intDC = int.Parse(strCif.Substring(8, 1)); // Intentamos convertir el ultimo caracter a entero
                if (intDC == intSum)
                    sw = true;
                else
                    sw = false;

            }
            catch
            {
                if (strLet.IndexOf(strCif.Substring(8, 1).ToUpper()) == intSum)
                    sw = true;
                else
                    sw = false;
            }

            return sw;
        }
    }
}
