﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Recurso_Administrativo.Clases;
using Recurso_Administrativo.Persistencia;

namespace Recurso_Administrativo
{
    /*************************************************************************************************************************
    * Nombre: NuevaAlta
    * Autor: José Juan Alvarado Almenara
    * Fecha: 16/11/2011 (Santa Margarita de Escocia)
    * Descripcion: Ventana que recogerá los datos del recurrente, representante o los mostrará en consulta
    *************************************************************************************************************************/
    public partial class AltasTerceros : Window
    {
        // Creamos los objetos globales que serán usados por la clase //
        TS_PROVINCIA _prov = new TS_PROVINCIA();
        TS_MUNICIPIO _mun = new TS_MUNICIPIO();
        TercerosServicio _terServ = new TercerosServicio();
        T_TERCEROS _terc = new T_TERCEROS();
   
        public AltasTerceros()
        {
            int i;
            
            InitializeComponent();
            cargarCombos();
            App.Current.Properties["grabado"] = "No";  // Creamos la "Variable global" para controlar si se han grabado los datos
            _terc = (T_TERCEROS)App.Current.Properties["_terc"];
            i = Convert.ToInt16(App.Current.Properties["Terceros"]); //Recogemos el valor para saber si es un alta de un recurrente, representante o consulta
            switch (i)
            {
                case 1:  // Alta de un recurrente
                    this.Title = "Alta Recurrente";
                    _terc.TER_TT_CF = 1;
                    break;
                case 2: // Alta de un representante
                    this.Title = "Alta Represenstante";
                    _terc.TER_TT_CF = 2;
                    break;
                case 3: // Consulta de datos de un recurrente
                    this.Title = "Consulta Datos Recurrente";
                    CargarDatos();
                    break;
                case 4: // Consulta de datos de un representante
                    this.Title = "Consulta Datos Representante";
                    CargarDatos();
                    break;
            }
            if (i <= 2) // Solo para altas 
            {
                txtNif.Text = _terc.TER_NIF;
                rbtNif.IsChecked = true;
            }
        }

        /*************************************************************************************************************************
         * Metodo: rbtNif_Checked
         * Autor: José Juan Alvarado Almenara
         * Fecha: 16/11/2011 (Santa Margarita de Escocia)
         * Descripcion: Si se ha pulsado el radio button del Nif habilitamos y mostramos los datos de los apellidos
         *************************************************************************************************************************/

        private void rbtNif_Checked(object sender, RoutedEventArgs e)
        {
            lblNom.Content = "Nombre:";
            lblApel1.IsEnabled = true;
            txtApel1.IsEnabled = true;
            lblApel2.IsEnabled = true;
            txtApel2.IsEnabled = true;
        }

        /*************************************************************************************************************************
        * Metodo: rbtCif_Checked
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Si se ha pulsado el radio button del Cif deshabilitamos los datos de los apellidos
        *************************************************************************************************************************/

        private void rbtCif_Checked(object sender, RoutedEventArgs e)
        {
            lblNom.Content = "Nombre de la Sociedad:";
            lblApel1.IsEnabled = false;
            txtApel1.IsEnabled = false;
            txtApel1.Text = "";
            lblApel2.IsEnabled = false;
            txtApel2.IsEnabled = false;
            txtApel2.Text = "";
        }

        /*************************************************************************************************************************
        * Metodo: CargarCombos
        * Recibe:
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Método para cargar los combos de la provincia y el municipio
        *************************************************************************************************************************/

        private void cargarCombos()
        {
            ProvinciaServicio _ps = new ProvinciaServicio();

            cmbProv.ItemsSource = _ps.getProvincias();
            cmbProv.SelectedValue = "PR_ClAVE";
            cmbProv.DisplayMemberPath = "PR_DESC";

            cmbMun.ItemsSource = _ps.getMunicipios();
            cmbMun.SelectedValue = "MU_CLAVE";
            cmbMun.DisplayMemberPath = "MU_DESC";
        }

        /*************************************************************************************************************************
         * Metodo: cmbProv_SelectionChanged
         * Autor: José Juan Alvarado Almenara
         * Fecha:  16/11/2011 (Santa Margarita de Escocia)
         * Descripcion: Evento del combo para controlar cuando se ha selecionado una provincia. En este caso, acto seguido carga 
         * en el combo de municipios los municipios pertenecientes a la provincia seleccionada.
         *************************************************************************************************************************/

        private void cmbProv_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ProvinciaServicio _ps = new ProvinciaServicio();

            _prov = (TS_PROVINCIA)cmbProv.SelectedItem;

            if (_mun.MU_DESC == null)
            {
                cmbMun.ItemsSource = _ps.getMunicipios(_prov.PR_CLAVE);
                cmbMun.SelectedValue = "MU_CLAVE";
                cmbMun.DisplayMemberPath = "MU_DESC";
            }
        }

        /*************************************************************************************************************************
         * Metodo: cmbMun_SelectionChanged
         * Autor: José Juan Alvarado Almenara
         * Fecha:  16/11/2011 (Santa Margarita de Escocia)
         * Descripcion: Evento del combo para controlar cuando se ha selecionado un municipio. Si no ha sido seleccionado antes una
         * provincia cargará el combo de provincia con la provincia a la que pertenece el municipio seleccionado
         *************************************************************************************************************************/

        private void cmbMun_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ProvinciaServicio _ps = new ProvinciaServicio();

            _mun = (TS_MUNICIPIO)cmbMun.SelectedItem;
            if (_prov.PR_DESC == null)
            {
                cmbProv.ItemsSource = _ps.getProvincias(_mun.MU_PR_CF);
                cmbProv.SelectedValue = "PR_ClAVE";
                cmbProv.DisplayMemberPath = "PR_DESC";
            }
        }

        /*************************************************************************************************************************
        * Metodo: cmdSalvar_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha:  16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Evento del boton salvar que comprueba una serie de parámetros antes de realizar la grabación de los datos
        *************************************************************************************************************************/

        private void cmdSalvar_Click(object sender, RoutedEventArgs e)
        {
            // Realizamos las comprobaciones antes de guardar los datos
            if (Comprobar())
            {
                _terc.TER_NIF = txtNif.Text.Trim().ToUpper();
                _terc.TER_NOMBRE = txtNom.Text.Trim().ToUpper();
                _terc.TER_APEL1 = txtApel1.Text.Trim().ToUpper();
                _terc.TER_APEL2 = txtApel2.Text.Trim().ToUpper();
                _terc.TER_DIRECCION = txtDir.Text.Trim().ToUpper();
                _terc.TER_MU_CF = _mun.MU_CLAVE;
                _terc.TER_PR_CF = _prov.PR_CLAVE;
                _terc.TER_CODPOS = txtCodPos.Text.Trim().ToUpper();
                _terc.TER_TFNO = txtTfn.Text.Trim().ToUpper();
                _terc.TER_MOVIL = txtMov.Text.Trim().ToUpper();
                _terc.TER_EMAIL = txtEmail.Text.Trim().ToUpper();
                try
                {
                    _terServ.AddTercero(_terc);
                    App.Current.Properties["Terceros"] = _terc;
                    App.Current.Properties["grabado"] = "Si";
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString(), "Error en la grabacion", MessageBoxButton.OK, MessageBoxImage.Error);
                }
                this.Close();
            }
        }

        /*************************************************************************************************************************
        * Metodo: Comprobar
        * Recibe:
        * Devuelve: booleano
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Este método se encargará de realizar una serie de comprobaciones previas a la grabación. En caso de existir
        * alguna anomalía informará al usuario de la misma.
        *************************************************************************************************************************/

        private bool Comprobar()
        {
            string mess ="";
            bool sw = false;
            // Crecacion de patrones para el 
            string patronCP = "^\\d{5}"; // Código postal
            string patronTfn = "^9\\d{8}"; // Teléfono fijo
            string patronMovil = "^6\\d{8}"; // teléfono movil
            string patronEmail = "^[\\w-\\.]+@([\\w-]+\\.)+[\\w-]{2,4}$"; // correo electrónico
            
            if (ComprobarNIFCIF()) // Compobamos si es un nif o cif válido
            {
                if (txtNom.Text.Trim() == "")  // Falta rellenar el nombre
                    mess = "Falta rellenar el nombre";
                else if ((txtApel1.Text.Trim() == "") && (rbtNif.IsChecked == true)) // Falta rellenar el apellido
                    mess = "Falta rellenar el 1º apellido";
                else if (txtDir.Text.Trim() == "") //Falta poner la dirección
                    mess = "Falta rellenar la dirección";
                else if (_prov.PR_DESC == null) // Falta seleccionar la provincia
                    mess = "Debe seleccionar una provincia";
                else if (_mun.MU_DESC == null) // Falta seleccionar el municipio
                    mess = "Debe selecionar un municipio";
                else if (txtCodPos.Text.Trim() == "") // Falta poner el CP
                    mess = "Falta rellenar el Código Postal";
               else if (!(System.Text.RegularExpressions.Regex.IsMatch(txtCodPos.Text, patronCP))) // o no cumple con el patron
                    mess = "Error en el codigo postal introducido.";
                else if (!(System.Text.RegularExpressions.Regex.IsMatch(txtTfn.Text, patronTfn)) && (txtTfn.Text.Trim() != "")) // El telfono fijo no cumple con el patron
                    mess = "Error en el número de telefono proporcionado";
                else if (!(System.Text.RegularExpressions.Regex.IsMatch(txtMov.Text, patronMovil)) && (txtMov.Text.Trim() != "")) // El telfono móvil no cumple con el patron
                     mess = "Error en el número de movil proporcionado";
                else if (!(System.Text.RegularExpressions.Regex.IsMatch(txtEmail.Text, patronEmail)) && (txtEmail.Text.Trim() != ""))// El correo electronico no cumple con el patron
                     mess = "Error en el formato del e-mail";
                else
                    sw = true;
            }
            else
                mess = "NIF/NIE/CIF no válido";
            if (!sw)
                MessageBox.Show(mess, "Error detectado", MessageBoxButton.OK, MessageBoxImage.Error);
            return sw;
        }

        /*************************************************************************************************************************
        * Metodo: ComprobarNIFCIF
        * Recibe:
        * Devuelve: booleano
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Comprueba si el NIF/CIF intoducidos son correctos.
        *************************************************************************************************************************/

        private bool ComprobarNIFCIF()
        {
            bool sw = true;

            if (rbtNif.IsChecked == true)  // Estamos dando de alta a una persona física
            {
                sw = _terServ.validarNif(txtNif.Text.ToUpper());
            }
            else if (rbtCif.IsChecked == true) // Estamos dando de alta a una persona jurídica (empresa)
                sw = _terServ.validarCIF(txtNif.Text.ToUpper());
            else
                sw = false;
            return sw;
        }

        /*************************************************************************************************************************
        * Metodo: cmdCancel_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha:  16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Evento del boton salir para cerrar la ventana
        *************************************************************************************************************************/

        private void cmdCancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        /*************************************************************************************************************************
        * Metodo: CargarDatos
        * Recibe:
        * Devuelve: 
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Carga los datos de un recurrente o representante por el cual estamos consultando
        *************************************************************************************************************************/

        private void CargarDatos()
        {
            if (_terServ.validarNif(_terc.TER_NIF))
                rbtNif.IsChecked = true;
            else 
                if(_terServ.validarCIF(_terc.TER_NIF))
                    rbtCif.IsChecked = true;

            txtNif.Text = _terc.TER_NIF;
            txtNif.IsReadOnly = true;
            txtNom.Text = _terc.TER_NOMBRE;
            txtNom.IsReadOnly = true;
            txtApel1.Text = _terc.TER_APEL1;
            txtApel1.IsReadOnly = true;
            txtApel2.Text = _terc.TER_APEL2;
            txtApel2.IsReadOnly = true;
            txtCodPos.Text = _terc.TER_CODPOS;
            txtCodPos.IsReadOnly = true;
            txtDir.Text = _terc.TER_DIRECCION;
            txtDir.IsReadOnly = true;
            txtEmail.Text = _terc.TER_EMAIL;
            txtEmail.IsReadOnly = true;
            txtMov.Text = _terc.TER_MOVIL;
            txtMov.IsReadOnly = true;
            txtTfn.Text = _terc.TER_TFNO;
            txtTfn.IsReadOnly = true;
            cmbProv.SelectedIndex = (_terc.TER_PR_CF==35?0:1); // Hacemos esto así ya que no se han cargado todas las provincias y municipios
            cmbProv.IsReadOnly = true;
            cmbProv.IsHitTestVisible = false;
            cmbMun.SelectedIndex = _terc.TER_MU_CF - 1;
            cmbMun.IsHitTestVisible = false;
            cmdSalvar.Visibility = Visibility.Hidden;
            cmdCancel.Content = "Salir";
        }

    }
}