﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Recurso_Administrativo.Clases;
using Recurso_Administrativo.Persistencia;

namespace Recurso_Administrativo
{

    /*********************************************************************************************************************************
    *   Nombre: EnvioCCDD
    *   Fecha: 21/11/2011 (San Gelasio I)
    *   Descripción: Ventana que mostrará los expedientes validados por el letrado y que recogerá los datos del CCDD al que se envía
    *   el expediente, así como las fechas de envío y recepción del mismo
    *   Autor: José Juan Alvarado Almenara
    *********************************************************************************************************************************/

    public partial class EnvioCCDD : Window
    {
        // Creamos los objetos globales que serán usados por la clase //
        ExpedienteF1Servicio _expF1Sev = new ExpedienteF1Servicio();
        CCDDServicio _ccddServ = new CCDDServicio();
        TS_CENTRODIRECTIVO _ccdd = new TS_CENTRODIRECTIVO();
        T_EXPEDIENTE_F1 _expF1 = new T_EXPEDIENTE_F1();

        public EnvioCCDD()
        {
            InitializeComponent();

            CargarGrid();
            CargarCombo();
        }

        /*************************************************************************************************************************
        * Metodo: dgdEnvCCDD_SelectionChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I)
        * Descripcion: Evento encargado de recoger el expediente que se ha seleccionado del grid y llamar al método CargarDatos
        * para mostrar todos los datos relativos a dicho expediente
        *************************************************************************************************************************/

        private void dgdEnvCCDD_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ExpedienteGrid _expGrid = new ExpedienteGrid();
            try
            {
                _expGrid = (ExpedienteGrid)dgdEnvCCDD.CurrentItem;

                LimpiarDatos();  // Limpiamos la pantalla con los datos anteriores
                if (_expGrid != null)
                    CargarDatos(_expGrid);
            }
            catch
            {
                CargarGrid();

            }
        }

        /*************************************************************************************************************************
        * Metodo: CargarDatos
        * Recibe: Objeto _expGrid
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I) 
        * Descripcion: Método cargar y mostrar los datos del expediente que ha sido seleccionado en el grid
        *************************************************************************************************************************/

        private void CargarDatos(ExpedienteGrid _expGrid)
        {
            TercerosServicio _terSrv = new TercerosServicio();
            UsuarioServicio _usrSev = new UsuarioServicio();
            T_TERCEROS _tercRec = new T_TERCEROS();
            T_TERCEROS _tercRep = new T_TERCEROS();
            T_USUARIO _usr = new T_USUARIO();


            _expF1 = _expF1Sev.GetExpedienteF1(_expGrid.ID);
            _expF1.EF1_FECFINPLAZO = _expF1.EF1_FECFINPLAZO;
            _tercRec = _terSrv.getTerceroId(Convert.ToInt32(_expF1.EF1_TER_REC_CF));
            _tercRep = _terSrv.getTerceroId(Convert.ToInt32(_expF1.EF1_TER_REP_CF));
            _usr = _usrSev.getUsrID(Convert.ToInt32(_expF1.EF1_USR_VAL_CF));
            txtNReg.Text = _expF1.EF1_NUMREG;
            txtTipRecurso.Text = _expGrid.Tipo_Recurso;
            txtFecInicio.Text = Convert.ToDateTime(_expF1.EF1_FECINI).ToShortDateString();
            txtFecFinPlazo.Text = Convert.ToDateTime(_expF1.EF1_FECFINPLAZO).ToShortDateString();
            txtNifRecur.Text = _tercRec.TER_NIF;
            txtNifRep.Text = (_tercRep == null ? "" : _tercRep.TER_NIF);
            txtValidado.Text = _usr.USR_NOMBRE + " " + _usr.USR_APELLIDOS;

            // Los siguientes if son para comprobar al cargar que aun no se han rellenado campos de los que faltan.
            // Si se han rellenado se muestran desabilitando la herramienta
            if (_expF1.EF1_FECENVCARTA != null) // Si se tiene la fecha de envio de la notificación la mostramos y no dejamos realizar cambios
            {
                dptFecEnvNot.Text = _expF1.EF1_FECENVCARTA.ToString();
                dptFecEnvNot.IsHitTestVisible = false;
            }
            if (_expF1.EF1_CD_CF != null) //Si se tiene el centro directivo
            {
                cmbCCDD.SelectedIndex = Convert.ToInt32(_expF1.EF1_CD_CF)  - 1 ;
                cmbCCDD.IsHitTestVisible = false;
            }
            if (_expF1.EF1_NREGINT != null)
            {
                txtNRegInt.Text = _expF1.EF1_NREGINT;
                txtNRegInt.IsReadOnly = true;
                dtpFecSendCCDD.Text = _expF1.EF1_FECENVCD.ToString();
                dtpFecSendCCDD.IsHitTestVisible = false;
            }
        }

        /*************************************************************************************************************************
        * Metodo: cmbCCDD_SelectionChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I)
        * Descripcion: Evento del combo para recoger el CCDD que se ha seleccionado dentro del combo
        *************************************************************************************************************************/

        private void cmbCCDD_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            _ccdd = (TS_CENTRODIRECTIVO)cmbCCDD.SelectedItem;
        }

        /*************************************************************************************************************************
        * Metodo: btnSend_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I)
        * Descripcion: Evento que se encargará cuando se pulse el boton salvar los datos se guarden las actualizaciones, limpiar
        * la pantalla y recargar el grid.
        *************************************************************************************************************************/

        private void btnSend_Click(object sender, RoutedEventArgs e)
        {
            if (Validar())
            {
                try
                {
                    _expF1Sev.ActualizarExpF1();
                    MessageBox.Show("Cambios guardados", "Salvar cambios", MessageBoxButton.OK, MessageBoxImage.Exclamation);
                    LimpiarDatos();
                    CargarGrid();
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString(), "No se ha podido realizar la actualización.", MessageBoxButton.OK, MessageBoxImage.Error);
                }

            }

        }

        /*************************************************************************************************************************
        * Metodo: CargarGrid
        * Recibe:
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I) 
        * Descripcion: Método para cargar el grid con los expedientes pendientes de validados por el Letrado.
        *************************************************************************************************************************/

        private void CargarGrid()
        {
            List<ExpedienteGrid> listExp = new List<ExpedienteGrid>();

            if(_expF1Sev.GetExpSendCCDD() != null) 
                listExp = _expF1Sev.GetExpSendCCDD().ToList();
            if (listExp.Count() > 0)
                dgdEnvCCDD.ItemsSource = listExp;
            else
                dgdEnvCCDD.ItemsSource = null;
        }

        /*************************************************************************************************************************
         * Metodo: CargarCombo
         * Recibe:
         * Devuelve:  
         * Autor: José Juan Alvarado Almenara
         * Fecha: 21/11/2011 (San Gelasio I)
         * Descripcion: Método para cargar el combo con los distintos CCDD
         *************************************************************************************************************************/

        private void CargarCombo()
        {
            cmbCCDD.ItemsSource = _ccddServ.getCCDD();
            cmbCCDD.SelectedValue = "CD_CLAVE";
            cmbCCDD.DisplayMemberPath = "CD_DESC";
        }

        /*************************************************************************************************************************
        * Metodo: Validar
        * Recibe: 
        * Devuelve: boolean
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I) 
        * Descripcion: Este método realizará una serie de comprobaciones antes de guardar los cambios producidos. Si se encuentra
        * algún fallo en los datos mostrará un mensaje al usuario para que los corrija e intente de nuevo la grabación.
        *************************************************************************************************************************/

        private bool Validar()
        {
            bool sw = false;
            string mess = "";
            if (_expF1.EF1_CLAVE > 0)
            {
                if (dptFecEnvNot.SelectedDate != null) // Si la fecha de notificacion interesado no es nula
                {
                    // Comprobamos que cumple una serie de requisitos sobre todo que las fecha no sea superior al dia actual, ni a la de fin de plazo
                    // que no se deje el numero de registro en blanco si se ha puesto la fecha de envío, etc.
                    if ((dptFecEnvNot.SelectedDate <= DateTime.Today) && (dptFecEnvNot.SelectedDate <= _expF1.EF1_FECFINPLAZO) && (dptFecEnvNot.SelectedDate >= _expF1.EF1_FECINI))
                    {
                        if (_ccdd.CD_DESC != null)
                        {
                            if (txtNRegInt.Text.Trim() != "")
                            {
                                if ((dtpFecSendCCDD.SelectedDate != null) && (dtpFecSendCCDD.SelectedDate >= dptFecEnvNot.SelectedDate) && (dtpFecSendCCDD.SelectedDate <= DateTime.Today) && (dtpFecSendCCDD.SelectedDate  <= _expF1.EF1_FECFINPLAZO))
                                {
                                    if (dtpFecRecCCDD.SelectedDate == null)
                                    {
                                        sw = true;
                                        _expF1.EF1_FECENVCARTA = dptFecEnvNot.SelectedDate;
                                        _expF1.EF1_CD_CF = _ccdd.CD_CLAVE;
                                        _expF1.EF1_NREGINT = txtNRegInt.Text.Trim().ToUpper();
                                        _expF1.EF1_FECENVCD = dtpFecSendCCDD.SelectedDate;
                                    }
                                    else
                                    {
                                        if ((dtpFecRecCCDD.SelectedDate >= dtpFecSendCCDD.SelectedDate) && (dtpFecRecCCDD.SelectedDate <= DateTime.Today) && (dtpFecRecCCDD.SelectedDate  <= _expF1.EF1_FECFINPLAZO))
                                        {
                                            sw = true;
                                            _expF1.EF1_FECENVCARTA = dptFecEnvNot.SelectedDate;
                                            _expF1.EF1_CD_CF = _ccdd.CD_CLAVE;
                                            _expF1.EF1_NREGINT = txtNRegInt.Text.Trim().ToUpper();
                                            _expF1.EF1_FECENVCD = dtpFecSendCCDD.SelectedDate;
                                            _expF1.EF1_FECRECCD = dtpFecRecCCDD.SelectedDate;
                                        }
                                        else
                                            mess = "Compruebe que la fecha de recepción del CCDD es mayor que la de envío al mismo, que esté en plazo y/o que no sea superior al día de hoy";
                                    }
                                }
                                else
                                    mess = "Compruebe la fecha de envio al CC DD no este el blanco, que sea igual o mayor a la de envío al interesado, que esté en plazo y/o que no sea superior al día de hoy";
                            }
                            else
                            {
                                sw = true;
                                _expF1.EF1_FECENVCARTA = dptFecEnvNot.SelectedDate;
                                _expF1.EF1_CD_CF = _ccdd.CD_CLAVE;
                            }
                        }
                        else
                        {
                            sw = true;
                            _expF1.EF1_FECENVCARTA = dptFecEnvNot.SelectedDate;
                        }
                    }
                    else
                        mess = "Compruebe la fecha de notificación con las fechas de hoy, la de fin de plazo y/o la de inicio";
                }
                else
                    mess = "Debe poner una fecha de envío al interesado.";
            }
            else
            {
                    mess = "Debe seleccionar un registro de la tabla";
            }
            if (!sw)
                MessageBox.Show(mess,"Comprobar Errores",MessageBoxButton.OK);
            return sw;
        }

        /*************************************************************************************************************************
        * Metodo: LimpiarDatos
        * Recibe: 
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 21/11/2011 (San Gelasio I) 
        * Descripcion: Método que se utilizará para limpiar los datos una vez grabado los cambios o si se ha seleccionado otro ex_
        * pediente del grid.
        *************************************************************************************************************************/

        private void LimpiarDatos()
        {
            txtNReg.Text = "";
            txtTipRecurso.Text = "";
            txtFecInicio.Text = "";
            txtFecFinPlazo.Text = "";
            txtNifRep.Text = "";
            txtNifRecur.Text = "";
            txtValidado.Text = "";
            dptFecEnvNot.Text = "";
            dptFecEnvNot.IsEnabled = true;
            txtNRegInt.Text = "";
            txtNRegInt.IsReadOnly = false;
            dtpFecRecCCDD.Text = "";
            dtpFecRecCCDD.IsEnabled = true;
            dtpFecSendCCDD.Text = "";
            dtpFecSendCCDD.IsEnabled = true;
            cmbCCDD.IsEnabled = true;
            CargarCombo();
        }
    }
}