﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Recurso_Administrativo.Clases;
using Recurso_Administrativo.Persistencia;

namespace Recurso_Administrativo
{

    /***********************************************************************************************************************************
    *   Nombre: Fase2
    *   Fecha:  22/11/2011 (Santa Cecilia)
    *   Descripción: Esta ventana se encarga de la recogida de datos en la Fase 2 del expediente. Solo pueden verse los expedientes que
    *   pertenencen al mismo CCDD que el usuario que se ha autentificado.
    *   Autor: José Juan Alvarado Almenara
    *********************************************************************************************************************************/

    public partial class Fase2 : Window
    {
        // Creamos los objetos globales que serán usados por la clase //
        ExpedienteF1Servicio _expF1Sev = new ExpedienteF1Servicio();
        ExpedienteF2Servicio _expF2Sev = new ExpedienteF2Servicio();
        TipoEstExpSer _desSer = new TipoEstExpSer();
        T_EXPEDIENTE_F1 _expF1 = new T_EXPEDIENTE_F1();
        T_EXPEDIENTE_F2 _expF2 = new T_EXPEDIENTE_F2();
        TS_DESESTIMACIONES _des = new TS_DESESTIMACIONES();
        bool existeF2 = false;

        public Fase2()
        {
            InitializeComponent();
            CargarCombo();
            CargarGrid();
        }

        /*************************************************************************************************************************
        * Metodo: CargarGrid
        * Recibe:
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método para cargar el grid con los expedientes pendientes que han pasado la Fase 1
        *************************************************************************************************************************/

        private void CargarGrid()
        {
            Usuario _usr = new Usuario();
            _usr = (Usuario)App.Current.Properties["Usurario"];

            if (_expF1Sev.GetExpF2(_usr.ccdd) != null)
                dtgListExp.ItemsSource = _expF1Sev.GetExpF2(_usr.ccdd).ToList();
        }

        /*************************************************************************************************************************
        * Metodo: dtgListExp_SelectionChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento para recoger el elemento seleccionado en el grid
        *************************************************************************************************************************/

        private void dtgListExp_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ExpedienteGrid _expGrid = new ExpedienteGrid();
            try
            {
                _expGrid = (ExpedienteGrid)dtgListExp.CurrentItem;
                if (_expGrid != null)
                {
                    CargarDatos(_expGrid);
                }
            }
            catch
            {
                CargarGrid();
            }
        }

        /*************************************************************************************************************************
        * Metodo: CargarDatos
        * Recibe: Objetod ExpedienteGrid 
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método para cargar los datos y mostrarlos por pantalla
        *************************************************************************************************************************/

        private void CargarDatos(ExpedienteGrid _expGrid)
        {
            TercerosServicio _terSrv = new TercerosServicio();
            UsuarioServicio _usrSev = new UsuarioServicio();
            T_TERCEROS _tercRec = new T_TERCEROS();
            T_TERCEROS _tercRep = new T_TERCEROS();
            T_USUARIO _usr = new T_USUARIO();

            //Cargamos los datos del Exp Fase 1 y los mostramos//
            _expF1 = _expF1Sev.GetExpedienteF1(_expGrid.ID);
            _expF1.EF1_FECFINPLAZO = _expF1.EF1_FECFINPLAZO;
            _tercRec = _terSrv.getTerceroId(Convert.ToInt32(_expF1.EF1_TER_REC_CF));
            _tercRep = _terSrv.getTerceroId(Convert.ToInt32(_expF1.EF1_TER_REP_CF));
            _usr = _usrSev.getUsrID(Convert.ToInt32(_expF1.EF1_USR_VAL_CF));
            txtNReg.Text = _expF1.EF1_NUMREG;
            txtNifRecur.Text = _tercRec.TER_NIF;
            if (_tercRep != null)
            {
                txtNifRep.Text = _tercRep.TER_NIF;
                txtNifRep.IsReadOnly = true;
            }
            txtFecEntCCDD.Text = Convert.ToDateTime(_expF1.EF1_FECRECCD).ToShortDateString();
            // Cargamos los datos de ExpF2 (si existe)
            _expF2 = _expF2Sev.GetRegistro(_expF1.EF1_CLAVE);
            if(_expF2 != null)
            {
                existeF2 = true;
                rbtInadmitido.IsEnabled = false;  //Si ya existe no se puede dar por inadmitido
                rbtFDocumentacion.IsChecked = true;
                if (_expF2.EF2_DE_CF == 3)
                    CargarCombo2();
                HabilitarVisiblidad();
                txtDocReq.Text = _expF2.EF2_OBSERVACIONES;
                txtDocReq.IsReadOnly = true; // No permitimos cambios
                // Comprobamos las fechas que han sido grabadas para mostrarlas e inhabilitar los datepickers
                if (_expF2.EF2_FECSOLDAT != null)
                {
                    dtpEnvSolDoc.SelectedDate = _expF2.EF2_FECSOLDAT;
                    dtpEnvSolDoc.IsHitTestVisible = false;
                }
                if (_expF2.EF2_FECNOTSOLDAT != null)
                {
                    dtpNotSolDoc.SelectedDate = _expF2.EF2_FECNOTSOLDAT;
                    dtpNotSolDoc.IsHitTestVisible = false;
                    dtpFinPlaEntDoc.SelectedDate = _expF2.EF2_FECFINPLAZODOC;
                }

            }

        }

        /*************************************************************************************************************************
        * Metodo: rbtInadmitido_Checked
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento que controla si se ha marcado el radio buton de inadmitido, en cuyo caso ocultamos el radio buton de 
        * falta de documentación. Un expediente inadmitido termina su proceso.
        *************************************************************************************************************************/

        private void rbtInadmitido_Checked(object sender, RoutedEventArgs e)
        {
            rbtFDocumentacion.Visibility = Visibility.Hidden;
        }

        /*************************************************************************************************************************
        * Metodo: rbtFDocumentacion_Checked
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento que controla si se ha marcado el radio buton de inadmitido, en cuyo caso ocultamos el radio buton de 
        * falta de documentación habilitando el resto de campos necesarios.
        *************************************************************************************************************************/

        private void rbtFDocumentacion_Checked(object sender, RoutedEventArgs e)
        {
            rbtInadmitido.IsEnabled = false;
            HabilitarVisiblidad();
        }

        /*************************************************************************************************************************
        * Metodo: CargarCombo
        * Recibe: 
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método para el combo con los tipos de desistimiento
        *************************************************************************************************************************/

        private void CargarCombo()
        {
            cmbEstExp.ItemsSource = _desSer.getDes();
            cmbEstExp.SelectedValue = "DE_CLAVE";
            cmbEstExp.DisplayMemberPath = "DE_DESC";
        }

        /*************************************************************************************************************************
        * Metodo: CargarCombo2
        * Recibe: 
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método para el combo con los tipos de desistimiento con todos los tipos.
        *************************************************************************************************************************/

        private void CargarCombo2()
        {
            cmbEstExp.ItemsSource = _desSer.getDes2();
            cmbEstExp.SelectedValue = "DE_CLAVE";
            cmbEstExp.DisplayMemberPath = "DE_DESC";
            cmbEstExp.SelectedIndex = 1;
        }

        /*************************************************************************************************************************
        * Metodo: btnSalvar_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento para guardar los datos registrados en la pantalla en la Fase 2 del expediente
        *************************************************************************************************************************/

        private void btnSalvar_Click(object sender, RoutedEventArgs e)
        {
            T_EXPEDIENTE_F2 _expF2_aux = new T_EXPEDIENTE_F2();
            if (Validar())
            {
                if (!existeF2)  // Es una alta
                {
                    _expF2_aux.EF2_EF1_CF = _expF1.EF1_CLAVE;
                    if (rbtInadmitido.IsChecked == true)
                        _expF2_aux.EF2_DE_CF = 1;
                    else
                    {
                        _expF2_aux.EF2_DE_CF = _des.DE_CLAVE;
                        _expF2_aux.EF2_OBSERVACIONES = _expF2_aux.EF2_OBSERVACIONES = txtDocReq.Text.Trim().ToUpper();
                        _expF2_aux.EF2_FECSOLDAT = dtpEnvSolDoc.SelectedDate;
                        _expF2_aux.EF2_FECNOTSOLDAT = dtpNotSolDoc.SelectedDate;
                        _expF2_aux.EF2_FECFINPLAZODOC = dtpFinPlaEntDoc.SelectedDate;
                        _expF2_aux.EF2_FECSOLINFLET = dtpSolInfLet.SelectedDate;
                        _expF2_aux.EF2_NREGINT = txtNRegInt.Text.Trim().ToUpper();
                        _expF2_aux.EF2_FECFINPLAZOINF = dtpFinPlaInfLet.SelectedDate;
                    }
                    _expF2Sev.AddExpediente(_expF2_aux);
                }
                else // es una actualización
                {
                    _expF2.EF2_DE_CF = (_des != null? _des.DE_CLAVE : Convert.ToByte(0));
                    _expF2.EF2_OBSERVACIONES = _expF2_aux.EF2_OBSERVACIONES = txtDocReq.Text.Trim().ToUpper();
                    _expF2.EF2_FECSOLDAT = dtpEnvSolDoc.SelectedDate;
                    _expF2.EF2_FECNOTSOLDAT = dtpNotSolDoc.SelectedDate;
                    _expF2.EF2_FECFINPLAZODOC = dtpFinPlaEntDoc.SelectedDate;
                    _expF2.EF2_FECSOLINFLET = dtpSolInfLet.SelectedDate;
                    _expF2.EF2_NREGINT = txtNRegInt.Text.Trim().ToUpper();
                    _expF2.EF2_FECFINPLAZOINF = dtpFinPlaInfLet.SelectedDate;
                    _expF2Sev.ActualizarExpF2();
                }
                LimpiarPantalla();
                CargarGrid();
            }

        }

        /*************************************************************************************************************************
        * Metodo: Validar
        * Recibe: 
        * Devuelve: boolean 
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método para validar los datos registrados en la ventana de la fase 2 antes de realizar la persistencia
        *************************************************************************************************************************/

        private bool Validar()
        {
            bool sw = false;
            string mess="";
            if (rbtInadmitido.IsChecked == false)
            {
                if (rbtFDocumentacion.IsChecked == true)
                {
                    if (txtDocReq.Text.Trim() != "")
                    {
                        if (dtpEnvSolDoc.SelectedDate == null)  // Si no tiene fecha de envio de solicitud 
                        {
                            if (dtpNotSolDoc.SelectedDate == null) //y no tiene fecha de notificacion 
                                sw = true; // permitimos la grabación de la fecha de envio sol. documentación
                            else
                                mess = "Debe de rellenar la Fecha Envío Solicitud Documentación.";
                        }
                        // Si tiene fecha de envio solicitud documentación comprobamos las fechas
                        else if ((dtpEnvSolDoc.SelectedDate <= DateTime.Today) && (dtpEnvSolDoc.SelectedDate >= _expF1.EF1_FECRECCD))
                        {
                            if (dtpNotSolDoc.SelectedDate == null) // Si la fecha de notificacion es nula
                                sw = true; // permitimos la grabación de la fecha de envio sol. documentación
                            // Si se ha rellenado la fecha de Notif. comprobamos
                            else if ((dtpNotSolDoc.SelectedDate <= DateTime.Today) && (dtpNotSolDoc.SelectedDate >= dtpEnvSolDoc.SelectedDate))
                            {
                                if (dtpSolInfLet.SelectedDate == null) // Si la fecha de solicitud Letrado no se ha rellenado
                                    sw = true; //Permitimos la grabación de la fecha de notificación
                                //Comprobamos que la fechas de solicitud no sea superior a la actual y que se encuentre entre la de notificación y la de entrada
                                else if ((dtpSolInfLet.SelectedDate <= DateTime.Today) && ((dtpSolInfLet.SelectedDate >= dtpNotSolDoc.SelectedDate) && (dtpSolInfLet.SelectedDate <= dtpFinPlaEntDoc.SelectedDate)))
                                {
                                    if (txtNRegInt.Text != "")
                                    {
                                        if((_expF1.EF1_TER_REP_CF == 0) || (_expF1.EF1_TER_REP_CF == null)) // no se ha grabado el representante por lo tanto hay que darle de alta
                                        {
                                            if (txtNifRep.Text != "") // Se ha rellenado el campo del representante y hay que realizar comprobaciones
                                            {
                                                if (AltaRepresentante(txtNifRep.Text) > 0)
                                                    sw = true;
                                                else
                                                    mess = "Modifique el NIF/CIF del reperesentante.";
                                            }
                                            else
                                                mess = "Hay que dar de alta al representante.";
                                        }
                                        else
                                            sw = true;
                                    }
                                    else
                                        mess = "Ha de proporcionar el Número de Reg. Interno";
                                }
                                else
                                    mess = "Comprobar la fecha de Envío al Letrado no se superior al día de hoy y que se encuentre entre las fecha de solicitud de documentación y fecha fin de notificación.";
                            }
                            else
                                mess = "Comprobar que la fecha de Notificación al interesado no sea posterior a la actual o que no sea inferior a la de envío de la notificación.";
                        }
                        else
                            mess = "Comprobar que la fecha de envio de la solicitud no sea posterior a la actual o que no sea anterior a la de entrada en el CC.DD.";
                    }
                    else
                        mess = "Falta rellenar la documentación requerida";
                }
            }
            else
                sw = true;
            if ((sw) && !(txtNifRep.IsReadOnly) && (txtNifRep.Text.Trim() != ""))
            {
                if (AltaRepresentante(txtNifRep.Text) > 0)
                    sw = true;
                else
                    mess = "Modifique el NIF/CIF del reperesentante.";
            }

            if (!sw)
                MessageBox.Show(mess);
            return sw;
        }

        /*************************************************************************************************************************
        * Metodo: cmbEstExp_SelectionChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento del combo para recoger el estado del expediente
        *************************************************************************************************************************/

        private void cmbEstExp_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            _des = (TS_DESESTIMACIONES)cmbEstExp.SelectedItem;
            if ((_des != null) &&(_des.DE_CLAVE == 2))  //si se selecciona desestimiento no dejamos ver el resto de campos
            {
                lblNRegInt.Visibility = Visibility.Hidden;
                txtNRegInt.Visibility = Visibility.Hidden;
                txtNRegInt.Text = null;
                lblFecFinPlaInfLet.Visibility = Visibility.Hidden;
                dtpFinPlaInfLet.Visibility = Visibility.Hidden;
                dtpFinPlaInfLet.SelectedDate = null;
                lblFecSolInfLet.Visibility = Visibility.Hidden;
                dtpSolInfLet.Visibility = Visibility.Hidden;
                dtpSolInfLet.SelectedDate = null;
            }
        }

        /*************************************************************************************************************************
        * Metodo: FechaFin
        * Recibe: DateTime (Fecha de inicio)
        * Devuelve: DateTime (Fecha de fin de plazo)
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método hallar cual será la fecha de fin de plazo contados 15 días desde la fecha de inicio. Son días hábiles
        * con lo cual no se ha de tener en cuenta los domingos.
        *************************************************************************************************************************/

        private DateTime FechaFin(DateTime fecIni)
        {
            int dias = 15;
            for (int i = 1; i <= dias; i++)
            {
                if (fecIni.AddDays(i).DayOfWeek == DayOfWeek.Sunday)
                    dias++;
            }

            return fecIni.AddDays(dias);
        }

        /*************************************************************************************************************************
        * Metodo: dtpNotSolDoc_SelectedDateChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento que al seleccionar una fecha del datepicker de notificación de solicitud de documentación habilitará
        * otros componenentes para poder recoger otra información.
        *************************************************************************************************************************/

        private void dtpNotSolDoc_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            if (dtpNotSolDoc.SelectedDate != null)
            {
                lblFecFinEntDoc.Visibility = Visibility.Visible;
                dtpFinPlaEntDoc.Visibility = Visibility.Visible;
                dtpFinPlaEntDoc.Text = FechaFin((DateTime)dtpNotSolDoc.SelectedDate).ToShortDateString();
                if ((_des.DE_CLAVE == 0) || (_des.DE_CLAVE == 3))
                {
                    lblNRegInt.Visibility = Visibility.Visible;
                    txtNRegInt.Visibility = Visibility.Visible;
                    lblFecFinPlaInfLet.Visibility = Visibility.Visible;
                    dtpFinPlaInfLet.Visibility = Visibility.Visible;
                    lblFecSolInfLet.Visibility = Visibility.Visible;
                    dtpSolInfLet.Visibility = Visibility.Visible;
                }
            }
        }

        /*************************************************************************************************************************
        * Metodo: dtpSolInfLet_SelectedDateChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento que al seleccionar una fecha del datepicker de solicitud de informe del letrado si el expdiente esta
        * en estado de posible desistimiento deja el estado a nulo, ya que sigue su curso.
        *************************************************************************************************************************/

        private void dtpSolInfLet_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            if (dtpSolInfLet.SelectedDate != null)
            {
                dtpFinPlaInfLet.SelectedDate = FechaFin((DateTime)dtpSolInfLet.SelectedDate);
                CargarCombo();
                cmbEstExp.SelectedIndex = -1;

            }
        }

        /*************************************************************************************************************************
        * Metodo: HabilitarVisiblidad
        * Recibe: 
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método para habilitar la visibilidad de los componentes a medida que se van rellenando otros
        *************************************************************************************************************************/

        private void HabilitarVisiblidad()
        {
            lblEstExp.Visibility = Visibility.Visible;
            cmbEstExp.Visibility = Visibility.Visible;
            lblDocReq.Visibility = Visibility.Visible;
            txtDocReq.Visibility = Visibility.Visible;
            lblFecPetDoc.Visibility = Visibility.Visible;
            dtpEnvSolDoc.Visibility = Visibility.Visible;
            lblFecNotSolDoc.Visibility = Visibility.Visible;
            dtpNotSolDoc.Visibility = Visibility.Visible;
        }

        /*************************************************************************************************************************
        * Metodo: AltaRepresentante
        * Recibe: string (NIF del representante)
        * Devuelve: int (Clave tabla terceros del representante)
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: En la fase 2 es necesario saber, para continuar, el representante. En caso de no estar dado de alta desde
        * el principio en este momento invocamos la ventana para la recogida de los datos del representante.
        *************************************************************************************************************************/

        private int AltaRepresentante(string strNif)
        {
            TercerosServicio _terSer = new TercerosServicio();
            T_TERCEROS _tercRep = new T_TERCEROS();
            int resul= 0;

            _tercRep = _terSer.getTercero(strNif);

            if (_tercRep == null) //Comprobamos que no existe el nif en la BBDD
            {
                mostrarAltaTerceros(2, _tercRep, txtNifRep.Text.ToUpper()); // en cuyo caso pedimos los datos del recurrente
                if (App.Current.Properties["grabado"].ToString().Equals("Si"))
                {
                    _tercRep = (T_TERCEROS)App.Current.Properties["Terceros"];
                    resul = _tercRep.TER_CLAVE;
                    _expF1.EF1_TER_REP_CF = resul;
                    _expF1Sev.ActualizarExpF1();
                }
            }
            else
            {
                if (_tercRep.TER_TT_CF == 1)
                {
                    resul = 0;
                    _tercRep.TER_CLAVE = 0; ;
                    MessageBox.Show("El representante existe dado de alta como recurrente", "", MessageBoxButton.OK);
                }
                else
                {
                    resul = _tercRep.TER_CLAVE;
                    _expF1.EF1_TER_REP_CF = resul;
                    _expF1Sev.ActualizarExpF1();
                }
            }
            return resul;
        }

        /*************************************************************************************************************************
        * Metodo: AltaRepresentante
        * Recibe: int (Entero para controlar que es un alta de representante), Objeto terceros, string (nif del representante
        * Devuelve:
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Metodo que llamará a la ventana de alta de terceros.
        *************************************************************************************************************************/

        private void mostrarAltaTerceros(int i, T_TERCEROS _terc, string nif)
        {
            _terc = new T_TERCEROS();
            _terc.TER_NIF = nif;
            App.Current.Properties["Terceros"] = i;
            App.Current.Properties["_terc"] = _terc;
            AltasTerceros _wAT = new AltasTerceros();
            _wAT.ShowDialog();
        }

        /*************************************************************************************************************************
        * Metodo: LimpiarDatos
        * Recibe: 
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Método que se utilizará para limpiar los datos una vez grabado los cambios o si se ha seleccionado otro ex_
        * pediente del grid.
        *************************************************************************************************************************/

        private void LimpiarPantalla()
        {
            txtNReg.Text= "";
            txtNifRep.Text = "";
            txtNifRecur.Text = "";
            txtNifRecur.IsReadOnly = true;
            txtFecEntCCDD.Text = "";
            rbtInadmitido.IsEnabled = true;
            rbtInadmitido.IsChecked = false;
            rbtFDocumentacion.IsEnabled = true;
            rbtFDocumentacion.IsChecked = false;
            txtDocReq.Text = "";
            txtDocReq.Visibility = Visibility.Hidden;
            dtpEnvSolDoc.SelectedDate = null;
            dtpEnvSolDoc.Visibility = Visibility.Hidden;
            dtpFinPlaEntDoc.SelectedDate = null;
            dtpFinPlaEntDoc.Visibility = Visibility.Hidden;
            dtpFinPlaInfLet.SelectedDate = null;
            dtpFinPlaInfLet.Visibility = Visibility.Hidden;
            dtpNotSolDoc.SelectedDate = null;
            dtpNotSolDoc.Visibility = Visibility.Hidden;
            dtpSolInfLet.SelectedDate = null;
            dtpSolInfLet.Visibility = Visibility.Hidden;
            txtNRegInt.Text = null;
            txtNRegInt.Visibility = Visibility.Hidden;
            lblDocReq.Visibility = Visibility.Hidden;
            lblFecFinEntDoc.Visibility = Visibility.Hidden;
            lblFecFinPlaInfLet.Visibility = Visibility.Hidden;
            lblFecNotSolDoc.Visibility = Visibility.Hidden;
            lblFecPetDoc.Visibility = Visibility.Hidden;
            lblFecPetDoc.Visibility = Visibility.Hidden;
            lblNRegInt.Visibility = Visibility.Hidden;
            lblFecSolInfLet.Visibility = Visibility.Hidden;
            CargarCombo();
        }

        /*************************************************************************************************************************
        * Metodo: btnCancel_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 22/11/2011 (Santa Cecilia)
        * Descripcion: Evento del boton cancel que al ser pulsado nos cierra la ventanda de Fase 2
        *************************************************************************************************************************/

        private void btnCancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }
    }
} 