﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Recurso_Administrativo.Clases;
using Recurso_Administrativo.Persistencia;

namespace Recurso_Administrativo
{
    /***********************************************************************************************************************************
     *   Nombre: NuevaAlta
     *   Fecha: 10/11/2011 (San Baudolino de Alessandria) 
     *   Descripción: Ventana que se encargará de la recogida de los datos de inicio de un nuevo expediente
     *   Autor: José Juan Alvarado Almenara
     *********************************************************************************************************************************/

    public partial class NuevaAlta : Window
    {
        // Creamos los objetos globales que serán usados por la clase //
        ExpedienteF1Servicio _expF1Ser = new ExpedienteF1Servicio();
        T_TERCEROS _tercRec = new T_TERCEROS();
        T_TERCEROS _tercRep = new T_TERCEROS();
        TS_TIPORECURSO _tr = new TS_TIPORECURSO();

        bool bolSalChan = true; // Variable lógica para controlar si se han realizado cambios y no se han guardado

        public NuevaAlta()
        {
            InitializeComponent();
            CargarCombo();  // Cargamos el combo con los tipos de recursos
        }

        /*************************************************************************************************************************
        * Metodo: cmbTipRecur_SelectionChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 10/11/2011 (San Baudolino de Alessandria)
        * Descripcion: Evento del combo para controlar cuando se ha cambiado un elemento dentro del mismo
        *************************************************************************************************************************/

        private void cmbTipRecur_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {        
            _tr = (TS_TIPORECURSO) cmbTipRecur.SelectedItem; // Guardamos en _tr el elemento seleccionado
            bolSalChan = false;
        }

        /*************************************************************************************************************************
        * Metodo: cmbCancel_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 15/11/2011 (San Eugenio de Toledo)
        * Descripcion: Evento para controlar la pulsación del botón salir
        *************************************************************************************************************************/

        private void cmbCancel_Click(object sender, RoutedEventArgs e)
        {
            MessageBoxResult result;
            if (!bolSalChan) // Si se quiere salir sin guardar los datos
            {
                // Mostramos mensajes
                result = MessageBox.Show("¿Quiere salir sin guardar los datos?", "Aviso", MessageBoxButton.YesNo, MessageBoxImage.Exclamation);
                if (result == MessageBoxResult.Yes) // Si la respuesta es afirmativa
                    this.Close(); //Salimos
            }
            else
                this.Close(); // y si se han guardado los cambios salimos
        }

        /*************************************************************************************************************************
        * Metodo: cmbSave_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 10/11/2011 (San Baudolino de Alessandria)
        * Descripcion: Evento para controlar la pulsación del botón Guardar. Antes de realizar la operación de guardar realiza una
        * serie de validaciones y se las pasa se salvan los datos en la BB.DD.
        *************************************************************************************************************************/

        private void cmbSave_Click(object sender, RoutedEventArgs e)
        {
            T_EXPEDIENTE_F1 _expF1 = new T_EXPEDIENTE_F1();
            if (validaciones())  // Pasamos una serie de validaciones antes de grabar
            {
                _expF1.EF1_NUMREG = txtNReg.Text.ToUpper();
                _expF1.EF1_TR_CF = _tr.TR_CLAVE;
                _expF1.EF1_FECREGOTROS = dtpFecRegOtros.SelectedDate;
                _expF1.EF1_FECREGCON = dtpFecRegCons.SelectedDate;
                _expF1.EF1_FECINI = dtpFecInicio.SelectedDate;
                _expF1.EF1_TER_REC_CF = _tercRec.TER_CLAVE;
                _expF1.EF1_TER_REP_CF = _tercRep.TER_CLAVE;
                try
                {
                    _expF1Ser.AddExpediente(_expF1);
                    MessageBox.Show("Nº Expediente " + _expF1.EF1_NUMREG.ToString() + " se ha grabado satisfactoriamente", "Información", MessageBoxButton.OK,MessageBoxImage.Information);
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString(), "No se ha podido realizar la grabación.", MessageBoxButton.OK,MessageBoxImage.Error);
                }
                this.Close();
            }
        }

        /*************************************************************************************************************************
         * Metodo: validaciones
         * Autor: José Juan Alvarado Almenara
         * Fecha: 10/11/2011 (San Baudolino de Alessandria)
         * Descripcion: Método encargado de comprobar que se han introducidos los datos obligatorios para realizar el alta del 
         * nuevo expediente, así como, que las fechas introducidas sean coherentes. En caso de aparecer algún fallo se le informa
         * al usuario del problema encontrado para que pueda solucionarlo y realizar la grabación del expediente.
         *************************************************************************************************************************/

        private bool validaciones()
        {
            bool sw = true;
            string mess="";
            TercerosServicio _tercs = new TercerosServicio();

            sw = !_expF1Ser.ExistRegistro(txtNReg.Text);  // No se pq pero no funciona dentro de un if. La solucion inic. sw con el valor devuelto
            if (sw)
            {
                if (_tr.TR_DESC == null) // No se ha seleccionado un tipo de recurso
                {
                    sw = false;
                    mess = "Debe seleccionar un tipo de recurso.";                 
                }
                else if (dtpFecRegCons.SelectedDate == null) //Fecha de reg. Consejeria nulo
                {
                    sw = false;
                    mess = "Debe seleccionar una fecha de entrada en la Consejería.";
                }
                else if (dtpFecInicio.SelectedDate == null) // Fecha de Inicio nulo
                {
                    sw = false;
                    mess = "Debe seleccionar una fecha de Inicio.";
                }
                else if (dtpFecRegCons.SelectedDate > DateTime.Now.Date) // Fecha de Reg Cons. mayor que la actual (sistema)
                {
                    sw = false;
                    mess = "La fecha de entrada en la Consejería no puede ser mayor que la actual.";
                }
                else if (dtpFecRegOtros.SelectedDate > DateTime.Now.Date) // Fecha de Reg Otros. mayor que la actual (sistema)
                {
                    sw = false;
                    mess = "La fecha de entrada en Otros Registros no puede ser mayor que la actual.";
                }
                else if (dtpFecInicio.SelectedDate > DateTime.Now.Date) // Fecha de Reg Incio. mayor que la actual (sistema)
                {
                    sw = false;
                    mess = "La fecha de Inicio no puede ser mayor que la actual.";
                }
                else if (dtpFecRegOtros.SelectedDate > dtpFecRegCons.SelectedDate) // Fecha Reg. Otros mayor Fecha Reg. Cons
                {
                    sw = false;
                    mess = "La fecha de entrada en Otros Registros debe ser anterior a la de entrada en la Consejería";
                }
                else if (dtpFecRegOtros.SelectedDate > dtpFecInicio.SelectedDate) // Fecha Reg. Otros mayor Fecha Inicio
                {
                    sw = false;
                    mess = "La fecha de entrada en Otros Registros deber ser anterior a la fecha de Inicio";
                }
                else if (dtpFecRegCons.SelectedDate > dtpFecInicio.SelectedDate) // Fecha Reg. Cons mayar Fecha Inicio
                {
                    sw = false;
                    mess = "La fecha de entrada en la Consejería deber ser anterior a la fecha de Inicio";
                }
                else if (txtNifRecur.Text == "")
                {
                    sw = false;
                    mess = "Debe proprocionarse el NIF/NIE/CIF del recurrente";
                }
            }
            else
                mess = "Número de Registro ya se encuentra dado de alta.";
            if (!sw) // Se ha detectado alguna anomalia y la mostramos
                MessageBox.Show(mess, "Error al realizar la grabación", MessageBoxButton.OK, MessageBoxImage.Information);
            else // No hay errores y debemos comprobar la existencia del recurrente y del representante si se ha rellenado el campo del nif
            {
                _tercRec = _tercs.getTercero(txtNifRecur.Text);
                if ((_tercRec == null)) //Comprobamos que no existe el nif en la BBDD
                {
                    mostrarAltaTerceros(1, _tercRec, txtNifRecur.Text.ToUpper()); // en cuyo caso pedimos los datos del recurrente
                    if (App.Current.Properties["grabado"].ToString().Equals("No")) // Si no se han grabado los datos del recurrente
                        sw = false; // no se permite la grabación del expediente
                    else
                        _tercRec = (T_TERCEROS)App.Current.Properties["Terceros"]; // en caso contrario recogemos los datos del recurrente
                }
                else
                {
                    if (_tercRec.TER_TT_CF == 2)
                    {
                        sw = false;
                        MessageBox.Show("El recurrente existe dado de alta como representante","",MessageBoxButton.OK,MessageBoxImage.Exclamation);
                    }
                }
                if ((txtNifRep.Text != "") && (sw)) // Se ha introducido el nif del representante
                {
                    _tercRep = _tercs.getTercero(txtNifRep.Text);
                    if (_tercRep == null) //Comprobamos que no existe el nif en la BBDD
                    {
                        mostrarAltaTerceros(2, _tercRep, txtNifRep.Text.ToUpper()); // en cuyo caso pedimos los datos del representante
                        if (App.Current.Properties["grabado"].ToString().Equals("No")) // Si no se han grabado los datos del representante
                            sw = false; // no se permite la grabación del expediente
                        else
                            _tercRep = (T_TERCEROS)App.Current.Properties["Terceros"]; // en caso contrario recogemos los datos del representante
                    }
                    else
                    {
                        if (_tercRep.TER_TT_CF == 1)
                        {
                            sw = false;
                            _tercRep.TER_CLAVE = 0; ;
                            MessageBox.Show("El representante existe dado de alta como recurrente", "", MessageBoxButton.OK, MessageBoxImage.Exclamation);
                        }
                    }

                }
            }
            return sw;
        }

        /*************************************************************************************************************************
        * Metodo: mostrarAltaTerceros
        * Recibe: Entero (Controlar que se va a dar de alta recurrente o representante), Objeto Terceros, string NIF
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 
        * Descripcion: Método que llamará a la ventana de alta a terceros para recoger los datos tanto del recurrete con del repre
        * sentante.
        *************************************************************************************************************************/

        private void mostrarAltaTerceros(int i, T_TERCEROS _terc, string nif)
        {
            _terc = new T_TERCEROS();
            _terc.TER_NIF = nif;
            App.Current.Properties["Terceros"] = i; // Guardamos en la "variable global" el tipo de tercero 1->Recurrente 2->Representante
            App.Current.Properties["_terc"] = _terc; //  Guardamos en la "variable global" el objeto terceros
            AltasTerceros _wAT = new AltasTerceros();
            _wAT.ShowDialog(); // Llamamos a la ventana de alta a terceros
        }

        /*************************************************************************************************************************
        * Metodo: CargarCombo
        * Recibe:
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 10/11/2011 (San Baudolino de Alessandria)
        * Descripcion: Método para cargar el combo del tipo de recurso
        *************************************************************************************************************************/

        private void CargarCombo()
        {
            TipoRecursoServicio _trs = new TipoRecursoServicio();

            cmbTipRecur.ItemsSource = _trs.getTipRec();
            cmbTipRecur.SelectedValue = "TR_CLAVE";
            cmbTipRecur.DisplayMemberPath = "TR_DESC";
        }

        /**************************************************************************************************************************
         * Por medio de los siguientes eventos vamos a controlar que se ha modificado para pedir en caso de cancelar si se quiere
         * salir sin grabar.
         * ************************************************************************************************************************/
        private void txtNReg_TextChanged(object sender, TextChangedEventArgs e)
        {
            bolSalChan = false;
        }

        private void dtpFecRegCons_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            bolSalChan = false;
        }

        private void dtpFecRegOtros_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            bolSalChan = false;
        }

        private void dtpFecInicio_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            bolSalChan = false;
        }

        private void txtNifRecur_TextChanged(object sender, TextChangedEventArgs e)
        {
            bolSalChan = false;
        }

        private void txtNifRep_TextChanged(object sender, TextChangedEventArgs e)
        {
            bolSalChan = false;
        }

    }
}
