﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Recurso_Administrativo.Clases;
using Recurso_Administrativo.Persistencia;

namespace Recurso_Administrativo
{
    /*********************************************************************************************************************************
    *   Nombre: ValidarExpd
    *   Fecha: 16/11/2011 (Santa Margarita de Escocia) 
    *   Descripción: Ventana que nos mostrara los expedientes de validar y que nos permitirá la validación de los mismos
    *   Autor: José Juan Alvarado Almenara
    *********************************************************************************************************************************/
    public partial class ValidarExpd : Window
    {
        // Creamos los objetos globales que serán usados por la clase //
        ExpedienteF1Servicio _expF1Sev = new ExpedienteF1Servicio();
        T_EXPEDIENTE_F1 _expF1 = new T_EXPEDIENTE_F1();

        public ValidarExpd()
        {
            InitializeComponent();
            CargarGrid();
        }

        /*************************************************************************************************************************
        * Metodo: dgdExpVal_SelectionChanged
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Evento encargado de recoger el expediente que se ha seleccionado del grid y llamar al método CargarDatos
        * para mostrar todos los datos relativos a dicho expediente
        *************************************************************************************************************************/

        private void dgdExpVal_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
             ExpedienteGrid _expGrid = new ExpedienteGrid();
             try
             {
                 _expGrid = (ExpedienteGrid)dgdExpVal.CurrentItem;
                 if (_expGrid != null)
                     CargarDatos(_expGrid);
             }
             catch
             {
                 CargarGrid();
             }
           
        }

        /*************************************************************************************************************************
        * Metodo: CargarDatos
        * Recibe: Objeto _expGrid
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia) 
        * Descripcion: Método cargar y mostrar los datos del expediente que ha sido seleccionado en el grid
        *************************************************************************************************************************/

        private void CargarDatos(ExpedienteGrid _expGrid)
        {
            TercerosServicio _terSrv = new TercerosServicio();
            T_TERCEROS _tercRec = new T_TERCEROS();
            T_TERCEROS _tercRep = new T_TERCEROS();

            _expF1 = _expF1Sev.GetExpedienteF1(_expGrid.ID);
            _expF1.EF1_FECFINPLAZO = FechaFin((DateTime)_expF1.EF1_FECINI);
            _tercRec = _terSrv.getTerceroId(Convert.ToInt32(_expF1.EF1_TER_REC_CF));
            _tercRep = _terSrv.getTerceroId(Convert.ToInt32(_expF1.EF1_TER_REP_CF));
            txtNReg.Text = _expF1.EF1_NUMREG;
            txtTipRecurso.Text = _expGrid.Tipo_Recurso;
            txtFecRegCons.Text=Convert.ToDateTime(_expF1.EF1_FECREGCON).ToShortDateString();
            txtFecRegOtros.Text = (_expF1.EF1_FECREGOTROS==null?"":Convert.ToDateTime(_expF1.EF1_FECREGOTROS).ToShortDateString());
            txtFecInicio.Text = Convert.ToDateTime(_expF1.EF1_FECINI).ToShortDateString();
            txtFecFinPlazo.Text = Convert.ToDateTime(_expF1.EF1_FECFINPLAZO).ToShortDateString();
            txtNifRecur.Text = _tercRec.TER_NIF;
            txtNifRep.Text = (_tercRep== null?"":_tercRep.TER_NIF);
            
        }

        /*************************************************************************************************************************
        * Metodo: FechaFin
        * Recibe: DateTime (Fecha de inicio)
        * Devuelve: DateTime (Fecha de fin de plazo)
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia) 
        * Descripcion: Método hallar cual será la fecha de fin de plazo contados 10 días desde la fecha de inicio. Son días hábiles
        * con lo cual no se ha de tener en cuenta los domingos.
        *************************************************************************************************************************/

        private DateTime FechaFin(DateTime fecIni)
        {
            int dias = 10;  // numero de dias
            for (int i = 1; i <= dias; i++)  // vemos si hay domingos y aumentamos un día más por cada domingo
            {
                if (fecIni.AddDays(i).DayOfWeek == DayOfWeek.Sunday)
                    dias++;
            }
            
            return fecIni.AddDays(dias);
        }

        /*************************************************************************************************************************
        * Metodo: btnValidar_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Evento que se encargará cuando se pulse el boton de grabar de salvar los datos, limpiar la pantalla y recargar
        * el grid.
        *************************************************************************************************************************/

        private void btnValidar_Click(object sender, RoutedEventArgs e)
        {
            Usuario _usr = new Usuario();

            _usr = (Usuario) App.Current.Properties["Usurario"];
            _expF1.EF1_USR_VAL_CF = _usr.clave;
            try
            {
                _expF1Sev.ActualizarExpF1();  // Actualizamos

                CargarGrid(); // Recargamos el Grid
                // Limpiamos los datos 
                txtNReg.Text = "";
                txtFecFinPlazo.Text = "";
                txtFecInicio.Text = "";
                txtFecRegCons.Text = "";
                txtFecRegOtros.Text = "";
                txtNifRecur.Text = "";
                txtNifRep.Text = "";
                txtTipRecurso.Text = "";
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString(), "No se ha podido realizar la validación.", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

        /*************************************************************************************************************************
        * Metodo: btnCancel_Click
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia)
        * Descripcion: Evento del botón salir para cerrar la ventana.
        *************************************************************************************************************************/

        private void btnCancel_Click(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        /*************************************************************************************************************************
        * Metodo: CargarGrid
        * Recibe:
        * Devuelve:  
        * Autor: José Juan Alvarado Almenara
        * Fecha: 16/11/2011 (Santa Margarita de Escocia) 
        * Descripcion: Método para cargar el grid con los expedientes pendientes de validar por el Letrado
        *************************************************************************************************************************/

        private void CargarGrid()
        {
            List<ExpedienteGrid> listExp = new List<ExpedienteGrid>();

            if(_expF1Sev.GetPendienteValidar() != null)
                listExp = _expF1Sev.GetPendienteValidar().ToList();
            if (listExp.Count() > 0)
                dgdExpVal.ItemsSource = listExp;
            else
                dgdExpVal.ItemsSource = null;
        }

    }
}
